==> haskell-vector-sized-1.6.1-149.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-sized.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-sized
version:              1.6.1
visibility:           public
id:                   vector-sized-1.6.1-46NXqyMEkci5xzuJS09WSw
key:                  vector-sized-1.6.1-46NXqyMEkci5xzuJS09WSw
license:              BSD-3-Clause
copyright:            2016 Ellie Hermaszewska
maintainer:           whats.our.vector.victor@monoid.al
author:               Ellie Hermaszewska
homepage:             https://github.com/expipiplus1/vector-sized#readme
synopsis:             Size tagged vectors
description:          Please see README.md
category:             Data
abi:                  50a4dd096f3fe4d28f51c85b907c9e85
exposed:              True
exposed-modules:
    Data.Vector.Generic.Mutable.Sized
    Data.Vector.Generic.Mutable.Sized.Internal
    Data.Vector.Generic.Sized Data.Vector.Generic.Sized.Internal
    Data.Vector.Mutable.Sized Data.Vector.Primitive.Mutable.Sized
    Data.Vector.Primitive.Sized Data.Vector.Sized
    Data.Vector.Storable.Mutable.Sized Data.Vector.Storable.Sized
    Data.Vector.Unboxed.Mutable.Sized Data.Vector.Unboxed.Sized

import-dirs:          /usr/lib/ghc-9.6.6/site-local/vector-sized-1.6.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vector-sized-1.6.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vector-sized-1.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-sized
hs-libraries:         HSvector-sized-1.6.1-46NXqyMEkci5xzuJS09WSw
depends:
    adjunctions-4.4.3-JFB4iJ93aO845aovoP0TqZ base-4.18.2.1
    binary-0.8.9.1 comonad-5.0.9-5bfOfNZGuHK7Og8aLM6Xot deepseq-1.4.8.1
    distributive-0.6.2.1-L1zs4X1vyqcJbGQmd1YXaS
    finite-typelits-0.2.1.0-9EEui2oD8E25kxbmiETZQs
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    indexed-list-literals-0.2.1.3-9boUXeBxkuoKVKIveMXc7U
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:
    /usr/share/doc/haskell-vector-sized/html/vector-sized.haddock

haddock-html:         /usr/share/doc/haskell-vector-sized/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-sized-1.6.1-150-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-sized.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-sized
version:              1.6.1
visibility:           public
id:                   vector-sized-1.6.1-59K7mBM48cmD2KkvSmeqM4
key:                  vector-sized-1.6.1-59K7mBM48cmD2KkvSmeqM4
license:              BSD-3-Clause
copyright:            2016 Ellie Hermaszewska
maintainer:           whats.our.vector.victor@monoid.al
author:               Ellie Hermaszewska
homepage:             https://github.com/expipiplus1/vector-sized#readme
synopsis:             Size tagged vectors
description:          Please see README.md
category:             Data
abi:                  2f877ce661947e722e320b23ff801f11
exposed:              True
exposed-modules:
    Data.Vector.Generic.Mutable.Sized
    Data.Vector.Generic.Mutable.Sized.Internal
    Data.Vector.Generic.Sized Data.Vector.Generic.Sized.Internal
    Data.Vector.Mutable.Sized Data.Vector.Primitive.Mutable.Sized
    Data.Vector.Primitive.Sized Data.Vector.Sized
    Data.Vector.Storable.Mutable.Sized Data.Vector.Storable.Sized
    Data.Vector.Unboxed.Mutable.Sized Data.Vector.Unboxed.Sized

import-dirs:          /usr/lib/ghc-9.6.6/site-local/vector-sized-1.6.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vector-sized-1.6.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vector-sized-1.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-sized
hs-libraries:         HSvector-sized-1.6.1-59K7mBM48cmD2KkvSmeqM4
depends:
    adjunctions-4.4.3-CGfiZ0Nwp52HytI706XQqX base-4.18.2.1
    binary-0.8.9.1 comonad-5.0.9-715y3Qio4tKCm1VNZVBtRL deepseq-1.4.8.1
    distributive-0.6.2.1-GSLXrb3mYHCCnRW3oVJKQJ
    finite-typelits-0.2.1.0-1c3QQ0Tukb28dmjRhepJ3O
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    indexed-list-literals-0.2.1.3-4iAjFHZyVObDchGMgqY8bu
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-vector-sized/html/vector-sized.haddock

haddock-html:         /usr/share/doc/haskell-vector-sized/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
